@@ -115,6 +115,8 @@ alwaysrunset = []
 azurealwaysrun = ""
 azurealwaysrunset = []
 upload = "true"
+createfile = "false"
+createpropertiesfile = "false"
 
 def find(name):
     currentdir = (
@@ -1222,7 +1224,7 @@ def runtestswithappsurify(*args):
     global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
     global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput, recursive, bitrise, executioncommand, githubactionsvariable, printcommand
     global azurefilter, replaceretry, webdriverio, percentage, endspecificrun, runnewtests, weekendrunall, newdays, azurefilteronall, azurevariablenum, time, commandset, alwaysrun, alwaysrunset
-    global azurealwaysrun, azurealwaysrunset, upload
+    global azurealwaysrun, azurealwaysrunset, upload, createfile, createpropertiesfile
     try:    
 
         
@@ -1311,6 +1313,8 @@ def runtestswithappsurify(*args):
         azurealwaysrun = ""
         azurealwaysrunset = []
         upload = "true"
+        createfile = "false"
+        createpropertiesfile = "false"
         # --testsuitesnameseparator and classnameseparator need to be encoded i.e. # is %23
 
         # Templates
@@ -2112,6 +2116,10 @@ def runtestswithappsurify(*args):
                 #    runnewtests = sys.argv[k+1]
                 if sys.argv[k] == "--noupload":
                     upload = "false"
+                if sys.argv[k] == "--createpropertiesfile":
+                    createpropertiesfile = "true"
+                if sys.argv[k] == "--createfile":
+                    createfile = "true"
                 if sys.argv[k] == "--help":
                     echo(
                         "please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyScriptInstallation"
@@ -2443,7 +2451,15 @@ def runtestswithappsurify(*args):
             printcommand = printcommand.replace("[[teststorun]]", testsrun)
             print(printcommand)
             
+        if createfile:
+            f= open("appsurifytests.txt","w+")
+            f.write(testsrun)
+            f.close()
 
+        if createpropertiesfile:
+            f= open("appsurifytests.properties","w+")
+            f.write(f"appsurifytests={testsrun}")
+            f.close()
         # if githubactionsvariable != "" and githubactionsvariable is not None:
         #    executioncommand = "echo \"\{githubactionsvariable\}={[[teststorun]]}\" >> $GITHUB_ENV"
 
